package com.srs.dormitory.mapper;

import java.util.List;

import com.srs.common.core.domain.AjaxResult;
import com.srs.dormitory.domain.DmsNewReg;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.dormitory.domain.Dto.DmsSearch;
import com.srs.dormitory.domain.Vo.DomInfo;
import com.srs.stureg.domain.SrsStuReg;
import org.apache.ibatis.annotations.Select;

/**
 * 新生宿舍Mapper接口
 *
 * @author srs
 * @date 2024-03-30
 */
public interface DmsNewRegMapper extends BaseMapper<DmsNewReg> {

    @Select("SELECT ksh FROM dms_new_reg WHERE del_flag = '0'")
    List<String> selectAllKsh();

    public DomInfo getStuDorm(DmsSearch param);

    public List<SrsStuReg> listStuInDorm(DmsSearch param);


    /**
     * 查询新生宿舍
     *
     * @param id 新生宿舍主键
     * @return 新生宿舍
     */
    public DmsNewReg selectDmsNewRegById(Long id);

    /**
     * 查询新生宿舍列表
     *
     * @param dmsNewReg 新生宿舍
     * @return 新生宿舍集合
     */
    List<DmsNewReg> selectDmsNewRegList(DmsNewReg dmsNewReg);

    /**
     * 新增新生宿舍
     *
     * @param dmsNewReg 新生宿舍
     * @return 结果
     */
    int insertDmsNewReg(DmsNewReg dmsNewReg);

    /**
     * 修改新生宿舍
     *
     * @param dmsNewReg 新生宿舍
     * @return 结果
     */
    int updateDmsNewReg(DmsNewReg dmsNewReg);

    /**
     * 删除新生宿舍
     *
     * @param id 新生宿舍主键
     * @return 结果
     */
    int deleteDmsNewRegById(Long id);

    /**
     * 批量删除新生宿舍
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDmsNewRegByIds(Long[] ids);
}
